@@ -223,6 +223,7 @@ class AalenAdditiveFitter(RegressionFitter):
         variance_hazards_ = np.zeros((n_deaths, d))
         v = np.zeros(d)
         start = time.time()
+        last_iteration = 0
 
         W = np.sqrt(weights)
         X = W[:, None] * X
@@ -248,7 +249,7 @@ class AalenAdditiveFitter(RegressionFitter):
             X[exits, :] = 0
 
             if show_progress and i % int((n_deaths / 10)) == 0:
-                print("\rIteration %d/%d, seconds_since_start = %.2f" % (i + 1, n_deaths, time.time() - start), end="")
+                print("\rIteration %d/%d, seconds_since_start = %.2f" % (i + 1, n_deaths, time.time() - start))
 
             last_iteration = i + 1
             # terminate early when there are less than (3 * d) subjects left, where d does not include the intercept.
