@@ -219,7 +219,7 @@ def rmst_plot(model, model2=None, t=np.inf, ax=None, text_position=None, **plot_
     return ax
 
 
-def qq_plot(model, ax=None, **plot_kwargs):
+def qq_plot(model, ax=None, scatter_color="k", **plot_kwargs):
     """
     Produces a quantile-quantile plot of the empirical CDF against
     the fitted parametric CDF. Large deviances away from the line y=x
@@ -291,7 +291,7 @@ def qq_plot(model, ax=None, **plot_kwargs):
 
     max_, min_ = quantiles[COL_EMP].max(), quantiles[COL_EMP].min()
 
-    quantiles.plot.scatter(COL_THEO, COL_EMP, c="none", edgecolor="k", lw=0.5, ax=ax)
+    quantiles.plot.scatter(COL_THEO, COL_EMP, c="none", edgecolor=scatter_color, lw=0.5, ax=ax)
     ax.plot([min_, max_], [min_, max_], c="k", ls=":", lw=1.0)
     ax.set_ylim(min_, max_)
     ax.set_xlim(min_, max_)
@@ -364,7 +364,14 @@ def remove_ticks(ax, x=False, y=False):
 
 
 def add_at_risk_counts(
-    *fitters, labels: Optional[Union[Iterable, bool]] = None, rows_to_show=None, ypos=-0.6, xticks=None, ax=None, **kwargs
+    *fitters,
+    labels: Optional[Union[Iterable, bool]] = None,
+    rows_to_show=None,
+    ypos=-0.6,
+    xticks=None,
+    ax=None,
+    at_risk_count_from_start_of_period=False,
+    **kwargs
 ):
     """
     Add counts showing how many individuals were at risk, censored, and observed, at each time point in
@@ -386,6 +393,9 @@ def add_at_risk_counts(
         make more positive to move the table up.
     xticks: list
         specify the time periods (as a list) you want to evaluate the counts at.
+    at_risk_count_from_start_of_period: bool, default False.
+        By default, we use the at-risk count from the end of the period. This is what other packages, and KMunicate suggests, but
+        the same issue keeps coming up with users. #1383, #1316 and discussion #1229. This makes the adjustment.
     ax:
         a matplotlib axes
 
@@ -489,14 +499,21 @@ def add_at_risk_counts(
             # a) to align with R (and intuition), we do a subtraction off the at_risk column
             # b) we group by the tick intervals
             # c) we want to start at 0, so we give it it's own interval
+            if at_risk_count_from_start_of_period:
+                event_table_slice = f.event_table.assign(at_risk=lambda x: x.at_risk)
+            else:
+                event_table_slice = f.event_table.assign(at_risk=lambda x: x.at_risk - x.removed)
 
-            event_table_slice = (
-                f.event_table.assign(at_risk=lambda x: x.at_risk - x.removed)
-                .loc[:tick, ["at_risk", "censored", "observed"]]
-                .agg({"at_risk": "min", "censored": "sum", "observed": "sum"})
-                .rename({"at_risk": "At risk", "censored": "Censored", "observed": "Events"})
-            )
-            counts.extend([int(c) for c in event_table_slice.loc[rows_to_show]])
+            if not event_table_slice.loc[:tick].empty:
+                event_table_slice = (
+                    event_table_slice.loc[:tick, ["at_risk", "censored", "observed"]]
+                    .agg({"at_risk": lambda x: x.tail(1).values, "censored": "sum", "observed": "sum"})  # see #1385
+                    .rename({"at_risk": "At risk", "censored": "Censored", "observed": "Events"})
+                    .fillna(0)
+                )
+                counts.extend([int(c) for c in event_table_slice.loc[rows_to_show]])
+            else:
+                counts.extend([0 for _ in range(n_rows)])
 
         if n_rows > 1:
             if tick == ax2.get_xticks()[0]:
@@ -669,7 +686,7 @@ def plot_lifetimes(
     Parameters
     -----------
     durations: (n,) numpy array or pd.Series
-      duration subject was observed for.
+      duration (relative to subject's birth) the subject was alive for.
     event_observed: (n,) numpy array or pd.Series
       array of booleans: True if event observed, else False.
     entry: (n,) numpy array or pd.Series
@@ -727,11 +744,11 @@ def plot_lifetimes(
 
     for i in range(N):
         c = event_observed_color if _iloc(event_observed, i) else event_censored_color
-        ax.hlines(i, _iloc(entry, i), _iloc(entry, i) + _iloc(durations, i), color=c, lw=1.5)
+        ax.hlines(i, _iloc(entry, i), _iloc(durations, i), color=c, lw=1.5)
         if left_truncated:
             ax.hlines(i, 0, _iloc(entry, i), color=c, lw=1.0, linestyle="--")
         m = "" if not _iloc(event_observed, i) else "o"
-        ax.scatter(_iloc(entry, i) + _iloc(durations, i), i, color=c, marker=m, s=13)
+        ax.scatter(_iloc(durations, i), i, color=c, marker=m, s=13)
 
     if label_plot_bars:
         ax.set_yticks(range(0, N))
