@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+from __future__ import annotations
 from typing import Union, Any, Tuple, List, Callable, Optional, Dict
 from datetime import datetime
 from functools import wraps
@@ -245,13 +245,12 @@ def restricted_mean_survival_time(
     https://bmcmedresmethodol.biomedcentral.com/articles/10.1186/1471-2288-13-152#Sec27
 
     """
-    if t is None:
-        t = np.inf
+    t = coalesce(t, np.inf)
 
     mean = _expected_value_of_survival_up_to_t(model_or_survival_function, t)
     if return_variance:
         sq = _expected_value_of_survival_squared_up_to_t(model_or_survival_function, t)
-        return (mean, sq - mean ** 2)
+        return (mean, sq - mean**2)
     else:
         return mean
 
@@ -266,7 +265,7 @@ def _expected_value_of_survival_up_to_t(model_or_survival_function, t: float = n
             ApproximationWarning,
         )
         sf = model_or_survival_function.loc[:t]
-        sf = sf.append(pd.DataFrame([1], index=[0], columns=sf.columns)).sort_index()
+        sf = pd.concat((sf, pd.DataFrame([1], index=[0], columns=sf.columns))).sort_index()
         return trapz(y=sf.values[:, 0], x=sf.index)
     elif isinstance(model_or_survival_function, lifelines.fitters.UnivariateFitter):
         # lifelines model
@@ -274,7 +273,7 @@ def _expected_value_of_survival_up_to_t(model_or_survival_function, t: float = n
         # if KM, we can compute exactly
         if isinstance(model, lifelines.KaplanMeierFitter):
             sf = model.survival_function_.loc[:t]
-            sf = sf.append(pd.DataFrame([model.predict(t)], index=[t], columns=sf.columns)).sort_index()
+            sf = pd.concat((sf, pd.DataFrame([model.predict(t)], index=[t], columns=sf.columns))).sort_index()
             sf = sf.reset_index()
             return (sf["index"].diff().shift(-1) * sf[model._label]).sum()
         else:
@@ -284,7 +283,7 @@ def _expected_value_of_survival_up_to_t(model_or_survival_function, t: float = n
 
 
 def _expected_value_of_survival_squared_up_to_t(
-    model_or_survival_function: Union["UnivariateFitter", pd.DataFrame], t: float = np.inf
+    model_or_survival_function: Union[UnivariateFitter, pd.DataFrame], t: float = np.inf
 ) -> float:
     r"""
     Compute the restricted mean survival time, RMST, of a survival function. This is defined as
@@ -994,7 +993,7 @@ def check_dimensions(df):
 
 
 def check_for_numeric_dtypes_or_raise(df):
-    nonnumeric_cols = [col for (col, dtype) in df.dtypes.iteritems() if dtype.name == "category" or dtype.kind not in "biuf"]
+    nonnumeric_cols = [col for (col, dtype) in df.dtypes.items() if dtype.name == "category" or dtype.kind not in "biuf"]
     if len(nonnumeric_cols) > 0:  # pylint: disable=len-as-condition
         raise TypeError(
             "DataFrame contains nonnumeric columns: %s. Try 1) using pandas.get_dummies to convert the non-numeric column(s) to numerical data, 2) using it in stratification `strata=`, or 3) dropping the column(s)."
@@ -1154,7 +1153,7 @@ def check_complete_separation_close_to_perfect_correlation(df: pd.DataFrame, dur
         durations = durations.sample(n=500, random_state=0)
 
     rank_durations = durations.argsort()
-    for col, series in df.iteritems():
+    for col, series in df.items():
         with np.errstate(invalid="ignore", divide="ignore"):
             rank_series = series.values.argsort()
             if abs(pearson_correlation(rank_durations, rank_series)) >= THRESHOLD:
@@ -1532,9 +1531,7 @@ class StepSizer:
     ATM it contains lots of "magic constants"
     """
 
-    def __init__(self, initial_step_size: Optional[float]) -> None:
-        initial_step_size = initial_step_size or 0.90
-
+    def __init__(self, initial_step_size: float):
         self.initial_step_size = initial_step_size
         self.step_size = initial_step_size
         self.temper_back_up = False
@@ -1576,7 +1573,7 @@ class StepSizer:
         return self.step_size
 
 
-def _to_1d_array(x) -> np.array:
+def _to_1d_array(x) -> np.ndarray:
     v = np.atleast_1d(x)
     try:
         if v.shape[0] > 1 and v.shape[1] > 1:
@@ -1586,18 +1583,24 @@ def _to_1d_array(x) -> np.array:
     return v
 
 
-def _to_list(x) -> List[Any]:
+def _to_list(x: Any) -> List[Any]:
     if not isinstance(x, list):
         return [x]
     return x
 
 
-def _to_tuple(x) -> Tuple[Any, ...]:
+def _to_tuple(x: Any) -> Tuple[Any, ...]:
     if not isinstance(x, tuple):
         return (x,)
     return x
 
 
+def _to_list_or_singleton(x: List[Any] | Any) -> List[Any] | Any:
+    if isinstance(x, list) and len(x) == 1:
+        return x[0]
+    return x
+
+
 def format_p_value(decimals) -> Callable:
     threshold = 0.5 * 10 ** (-decimals)
     return lambda p: "<%s" % threshold if p < threshold else "{:4.{prec}f}".format(p, prec=decimals)
@@ -1607,7 +1610,7 @@ def format_exp_floats(decimals) -> Callable:
     """
     sometimes the exp. column can be too large
     """
-    threshold = 10 ** 5
+    threshold = 10**5
     return lambda n: "{:.{prec}e}".format(n, prec=decimals) if n > threshold else "{:4.{prec}f}".format(n, prec=decimals)
 
 
@@ -1822,7 +1825,7 @@ def find_best_parametric_model(
                     entry=entry,
                     alpha=alpha,
                     ci_labels=ci_labels,
-                    timeline=timeline
+                    timeline=timeline,
                 )
             score_ = eval_(model)
 
@@ -1927,7 +1930,6 @@ class CovariateParameterMappings:
         # in pandas 0.23.4, the Xs as a dict is sorted differently from the Xs as a DataFrame's columns
         # hence we need to reorder, see https://github.com/CamDavidsonPilon/lifelines/issues/931
         Xs_df = pd.concat(Xs, axis=1, names=("param", "covariate")).astype(float)
-        Xs_df = Xs_df[list(self.mappings.keys())]
 
         # we can't concat empty dataframes and return a column MultiIndex,
         # so we create a "fake" dataframe (acts like a dataframe) to return.
@@ -1935,6 +1937,7 @@ class CovariateParameterMappings:
         if Xs_df.size == 0:
             return {p: pd.DataFrame(index=df.index) for p in self.mappings.keys()}
         else:
+            Xs_df = Xs_df[list(self.mappings.keys())]
             return Xs_df
 
     def keys(self):
